@@ -15,12 +15,11 @@ from sklearn.metrics import confusion_matrix
 
 from exputils.io import create_filepath
 
-# TODO generalize confusion matrix to multiple discrete RVs with a
-# ConfusionTensor class, which would be the parent to ConfusionMatrix
+# TODO ConfusionTensor: generalize confusion matrix to multiple discrete RVs
+# with a ConfusionTensor class, which would be the parent to ConfusionMatrix
 
 # TODO consider ways to interlink this with LabelEncoder better. If necessary
 
-
 class ConfusionMatrix(object):
     """Confusion matrix for nominal data that wraps the
     sklearn.metrics.confusion_matrix. Rows are the known labels and columns are
@@ -36,6 +35,15 @@ class ConfusionMatrix(object):
         labels : np.ndarray, optional
             The labels for the row and columns of the confusion matrix
         """
+
+        # TODO Add optional class weights attribute, allowing it to be
+        # overwritten for when the measures are claculated via a param
+
+        # TODO add sample weights param to init here to affect calc of conf
+
+        # TODO perhaps add a matrix of belief/reliability per pairwise class
+        # expressed by some probability per element
+
         if preds is None:
             if (
                 (
@@ -191,6 +199,7 @@ class ConfusionMatrix(object):
             if True, averages all true class rates together. Otherwise, returns
             the true rate per class in order of labels.
         """
+        # TODO check this and make a unit test for it.
         #recalls = np.diagonal(self.mat) / self.mat.sum(axis=1)
         if label is None:
             tp = self.true_positive()
@@ -592,3 +601,30 @@ class ConfusionMatrix(object):
                 loaded_conf_mat = h5f[conf_mat_key][:]
 
         return ConfusionMatrix(loaded_conf_mat, labels=labels)
+
+
+class ConfusionMatrices(ConfusionMatrix):
+    """Multiple confusion matrices with an arbitrary tensor serving as the
+    indices, where each index is a confusion matrix. The indexing tensor may
+    consist of nominal values, thus using the NominalDataEncoder.
+
+    This extends ConfusionMatrix and is a slice of the sparse ConfusionTensor
+    if each of the different confusion matrices were different discrete random
+    variables being compared.
+    """
+    def __init__(self):
+        raise NotImplementedError()
+
+
+class ConfusionTensor(ConfusionMatrix):
+    """A Confusion Tensor of M dimensions all of length N, resulting in the
+    shape `[N_1, N_2, ..., N_M]`.
+    """
+    def __init__(self):
+        raise NotImplementedError()
+
+    # TODO All the above measures need generalized such that they are applied
+    # to a matrix slice. The idea is to generalize them for this Tensor or a
+    # slice of this Tensor, thus needing to work on sparse np.ndarrays and
+    # easily apply to both cases, w/ this possibly being the Parent of
+    # ConfusionMatrix and ConfusionMatrices.
