@@ -71,10 +71,25 @@ class NumpyJSONEncoder(json.JSONEncoder):
         return o.__dict__
 
 
+def filename_append(filename, suffix):
+    """Appends text to the end of the filename before the file extention."""
+    root, ext = os.path.splitext(filename)
+
+    if ext:
+        # TODO add optional to ignore ext if fits some pattern.
+        # Perhaps add given extenstion to ease respecting the extention in
+        # cases where the existing setup fails
+
+        return f'{root}{suffix}{ext}'
+
+    # If there is no extention, simply append suffix
+    return f'{filename}{suffix}'
+
+
 def create_filepath(
     filepath,
     overwrite=False,
-    datetime_fmt='_%Y-%m-%d_%H-%M-%S',
+    datetime_fmt='_%Y-%m-%d_%H-%M-%S.%f',
 ):
     """Ensures the directories along the filepath exists. If the file exists
     and overwrite is False, then the datetime is appeneded to the filename
@@ -87,10 +102,6 @@ def create_filepath(
     follows the period, then the datetime is appeneded to the end of the file
     if it already exists.
     """
-
-    # TODO add given extenstion to ease respecting the extention in cases where
-    # the existing setup fails
-
     # Check if file already exists
     if not overwrite and os.path.isfile(filepath):
         logging.warning(
@@ -102,32 +113,26 @@ def create_filepath(
         )
 
         # NOTE beware possibility of program writing the same file in parallel
-        parts = filepath.rpartition('.')
-        if parts[0]:
-            if parts[2] and os.path.sep in parts[2]:
-                # No extension and path separator in part after period
-                filepath = filepath + datetime.now().strftime(datetime_fmt)
-            else:
-                # Handles extension
-                filepath = (
-                    parts[0] + datetime.now().strftime(datetime_fmt) + parts[1]
-                    + parts[2]
-                )
-        else:
-            # handles case with no extension
-            filepath = filepath + datetime.now().strftime(datetime_fmt)
+        filepath = filename_append(
+            filepath,
+            datetime.now().strftime(datetime_fmt),
+        )
 
         logging.warning('The filepath has been changed to: %s', filepath)
     else:
-        # ensure the directory exists
-        dir_path = filepath.rpartition(os.path.sep)
-        if dir_path[0]:
-            os.makedirs(dir_path[0], exist_ok=True)
+        # Ensure the directory exists
+        dir_path = os.path.dirname(filepath)
+        if dir_path:
+            os.makedirs(dir_path, exist_ok=True)
 
     return filepath
 
 
-def create_dirs(filepath, overwrite=False, datetime_fmt='_%Y-%m-%d_%H-%M-%S'):
+def create_dirs(
+    filepath,
+    overwrite=False,
+    datetime_fmt='_%Y-%m-%d_%H-%M-%S.%f',
+):
     """Ensures the directory path exists. Creates a sub folder with current
     datetime if it exists and overwrite is False.
     """
@@ -156,12 +161,26 @@ def create_dirs(filepath, overwrite=False, datetime_fmt='_%Y-%m-%d_%H-%M-%S'):
     return filepath
 
 
+def write(file, mode='x', *args, **kwargs):
+    """Convenience wrapper for python open file and safely write using
+    create_filepath, appending datetime if already existing. This simply
+    handles the exclusive write fail case.
+    """
+    if 'x' not in mode or 'r' in mode or 'w' in mode or '+' in mode:
+        raise ValueError(
+            "exputils.io.write() only supports exclusive creation. `mode='x'`",
+        )
+
+    # Using create_filepath ensures any directories are made and no overwriting
+    return open(create_filepath(file), mode, *args, **kwargs)
+
+
 def save_json(
     filepath,
     results,
     deep_copy=True,
     overwrite=False,
-    datetime_fmt='_%Y-%m-%d_%H-%M-%S',
+    datetime_fmt='_%Y-%m-%d_%H-%M-%S.%f',
 ):
     """Saves the content in results and additional info to a JSON.
 
